@@ -1,24 +1,30 @@
 package App::PerlXLock;
+$App::PerlXLock::VERSION = '0.08';
 use strict;
 use warnings;
 use base 'Exporter';
-our $VERSION = "0.07";
 our @EXPORT  = qw(main_loop);
-use Inline C => Config => LIBS => '-lX11';
-use Inline
-  C       => "DATA",
-  NAME    => "App::PerlXLock",
-  VERSION => '0.07',
-  INC     => '/usr/include';
 
-END {
-    Inline->init();
+BEGIN {
+   use constant PLOCK_PASSWORD => $ENV{PLOCK_PASSWORD};
 }
 
+sub detect_x11 {
+   my $pkg = `pkg-config --cflags --libs x11`;
+   if($? != 0){
+      die "Could not detect x11 using pkg-config (perhaps you are missing libx11)";
+   }
+   return $pkg;
+}
+
+use App::PerlXLock::Inline C => Config => LIBS => detect_x11();
+use App::PerlXLock::Inline C => "DATA";
+
 my @buffer;
 my @windows;
 my @screens;
 
+
 sub lock_all {
     my $d = shift();
     for ( 0 .. screen_count($d) - 1 ) {
@@ -36,7 +42,7 @@ sub shadow_readable {
 }
 
 sub password_accessible {
-    $ENV{PLOCK_PASSWORD} || ( has_shadow() && shadow_readable() );
+    PLOCK_PASSWORD || ( has_shadow() && shadow_readable() );
 }
 
 sub check_event {
@@ -46,7 +52,7 @@ sub check_event {
 
 sub check_password {
     my $pw = shift;
-    defined( $ENV{PLOCK_PASSWORD} ) && return($ENV{PLOCK_PASSWORD} eq $pw);
+    defined( PLOCK_PASSWORD ) && return(PLOCK_PASSWORD eq $pw);
     check_unix_password($pw) == 0;
 }
 
@@ -82,7 +88,7 @@ sub unlock_all {
     destroy_window( $d, $_ ) for (@windows);
 }
 
-unless ( $ENV{PLOCK_PASSWORD} ) {
+unless ( PLOCK_PASSWORD ) {
     has_shadow()
       || print "/etc/shadow does not exist. Xlock is not password protected.\n";
     shadow_readable
@@ -106,7 +112,7 @@ SV *open_connection(){
     Display *display;
     SV *d_sv;
     SV *d_sv_ref;
-    display = XOpenDisplay("0:0");
+    display = XOpenDisplay(NULL);
     if (display == NULL){
         croak("Could not open X display connection.");
     }
@@ -150,7 +156,7 @@ int open_lock(SV *disp_ref, int screen){
     status = XMapRaised(display, window);
     XRaiseWindow(display, window);
 
-    XSync(display,false);
+    XSync(display,0);
 
     XSelectInput(display, root, SubstructureNotifyMask);
     return window;
